package
Version:
v0.2.2
Opens a new window with list of versions in this module.
Published: May 10, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GeneratePKCE generates a code verifier and code challenge for PKCE
SignState signs state data with HMAC and returns base64 encoded state
func ValidatePKCE(verifier, challenge string) bool
ValidatePKCE validates that a code verifier matches a code challenge
type StateData struct {
WorkspaceID string `json:"workspace_id"`
ProviderID string `json:"provider_id"`
Nonce string `json:"nonce"`
IAT time.Time `json:"iat"`
}
VerifyState verifies and unpacks the signed state
Source Files
¶
Click to show internal directories.
Click to hide internal directories.